@@ -37,7 +37,7 @@ class ApoJWT():
             if self.token_f is None:
                 raise TypeError("ApoJWT requires the token_finder attribute to be defined for validating JWTs")
             token = self.token_f()
-            jwt.decode(token, self.secret, issuer=self.iss, algorithms=[self.algo])
+            jwt.decode(token, self.secret, issuer=self.iss, audience="default", algorithms=[self.algo])
             return fn(*args, **kwargs)
         return wrapper
         
@@ -91,7 +91,7 @@ class ApoJWT():
             - aud: Audience
             - iat: Issued At
         """
-
+        aud.append("default")
         payload = {
             "exp": int(exp),
             "nbf": datetime.now(tz=timezone.utc),
